@@ -136,8 +136,11 @@ class App(Generic[GenericDependencyContainer]):
                     callback=partial(s_app.ctx.rt_broadcaster.broadcast, resolve_callback=resolver),
                     use_nested_classes=use_nested_classes)
             await self.container.init_resources(s_app.ctx.channel)
+
             if loader := self.container.addon_loader():
-                await loader.first_init()
+                loader.register_channel_middleware()
+                if s_app.m.pid == max([w['pid'] for name, w in s_app.m.workers.items() if "Sanic-Server" in name]):
+                    await loader.first_init()
 
         async def reg_metrics(s_app: Sanic):
             async def give_metric(metric: Metric):
