@@ -3,10 +3,11 @@ from typing import Any, Dict
 from loguru import logger
 
 from web_foundation import settings
+from web_foundation.resources.resource import Resource
 from web_foundation.resources.stores.interface import DataStore
 
 
-class InMemoryDictStore(DataStore):
+class InMemoryDictStore(Resource[dict], DataStore):
     need_sync = True
     _storage: Dict
 
