@@ -22,19 +22,20 @@ def validate_dto(dto_cls: Type[PdModel] | None,request: Request) -> PdModel | No
     except PdValidationError as ex:
         failed_fields = ex.errors()
         fields = [field["loc"][-1] for field in failed_fields]
-        commment_str = "Some of essential params failed : " + ", ".join(
-            [field["loc"][-1] + " - " + field["msg"] for field in failed_fields])
-        message = commment_str
+        # commment_str = "Some of essential params failed : " + ", ".join(
+        #     [field["loc"][-1] + " - " + field["msg"] for field in failed_fields])
+        comment_str = f"""Some essential params failed: {", ".join([f'{field["loc"][-1]} - {field["msg"]}' for field in failed_fields])}"""
         context = {
             "fields": fields,
-            "comment": commment_str
+            "comment": comment_str
         }
-        raise ValidationError(message=message,
+        raise ValidationError(message=comment_str,
                               context=context)
 
 
 def dto_validation_error_format(exeption: PdValidationError):
     failed_fields = exeption.errors()
-    commment_str = "Some of essential params failed : " + ", ".join(
-        [str(field["loc"][-1]) + " - " + field["msg"] for field in failed_fields])
-    return commment_str
+    # commment_str = "Some essential params failed : " + ", ".join(
+    #     [str(field["loc"][-1]) + " - " + field["msg"] for field in failed_fields])
+    comment_str = f"""Some essential params failed: {", ".join([f'{field["loc"][-1]} - {field["msg"]}' for field in failed_fields])}"""
+    return comment_str
